@@ -75,25 +75,39 @@ def convert_to_json(text: str) -> Any:
     """
     text = remove_think_section(text)
     text = text.strip()
+    converted_json = None
 
     try:
         if text.startswith("```json"):
             text = text.strip("```json\n")
+
+        # 首先尝试直接解析JSON
+        converted_json = json.loads(text)
+    except json.JSONDecodeError:
         try:
-            return json.loads(text)
-        except json.JSONDecodeError:
             # 尝试使用eval作为备选方案（谨慎使用）
+            converted_json = eval(text)
+        except:
+            # 如果eval也失败，尝试提取JSON字符串
             try:
-                return eval(text)
+                extracted_json = extract_json_from_string(text)
+                if extracted_json:
+                    converted_json = json.loads(extracted_json)
             except:
                 pass
-    except Exception:
-        pass
 
-    # 新增：尝试用 extract_json_from_string 提取
-    extracted_json = extract_json_from_string(text)
-    if extracted_json:
-        return json.loads(extracted_json)
+    if converted_json is not None:
+        if "answer" in converted_json:  # zhipu 'glm-4-flash-250414' 模型会返回 answer 字段
+            answer = converted_json["answer"]
+            if isinstance(answer, (dict, list)):
+                return answer
+            elif isinstance(answer, str):
+                # 只对字符串类型的answer尝试递归解析
+                return convert_to_json(answer)
+            else:
+                return answer
+        else:
+            return converted_json
 
     print("无法解析为json格式:")
     print(text)
