@@ -6,7 +6,7 @@
 import time
 from funcguard.printer import print_line
 from typing import Dict, Tuple, Any, Optional
-from ..message import prepare_messages, rebuild_messages_single_image
+from ..message import prepare_messages, rebuild_messages_single_image, convert_images_to_base64
 
 
 # 图片下载相关的错误关键词列表
@@ -22,6 +22,7 @@ DEFAULT_RETRY_KEYWORDS = [
     "Allocated quota exceeded, please increase your quota limit",
     "Max retries exceeded with url",
     "Requests rate limit exceeded, please try again later",
+    "Free credits temporarily have rate limits",  # vercel
 ]
 
 DEFAULT_RETRY_KEYWORDS.extend(IMAGE_DOWNLOAD_ERROR_KEYWORDS)
@@ -63,12 +64,27 @@ class RetryHandler:
         error_message = str(e)
         response = getattr(e, 'response', None)
 
-        if response is not None:
+        # 如果异常对象本身就是response（来自handle_response的直接抛出）
+        if hasattr(e, 'model_dump'):
+            response = e
+
+        if response:
             try:
-                if hasattr(response, 'json'):
+                if hasattr(response, 'model_dump'):  # 兼容 openai
+                    res = response.model_dump()
+                    error = res.get("error", {})
+                    message = error.get("message", "")
+                    metadata = error.get("metadata", {})
+                    raw = metadata.get("raw", "")
+                    provider_name = metadata.get("provider_name", "")
+                    error_message = f"message: {message} : provider: {provider_name} , {raw}"
+
+                # hasattr 检查 response 是否有 json 方法
+                elif hasattr(response, 'json'):
                     res = response.json()
                     error = res.get("error", res.get("errors", {}))
                     error_message = error.get("message", str(e))
+
             except (AttributeError, ValueError):
                 error_message = str(e)
 
@@ -104,12 +120,17 @@ class RetryHandler:
             img_list = message_config["img_list"]
             print(f"img_list: {img_list}")
 
+            # 第3次尝试时，检测图片格式并进行base64转换
+            if api_retry_count == 1 and img_list:
+                print(f"尝试将图片转换为base64格式...")
+                img_list = convert_images_to_base64(img_list)
+
             messages = rebuild_messages_single_image(
                 self.platform,
                 message_config["system_prompt"],
                 message_config["user_text"],
-                message_config["include_img"],
-                img_list,
+                reject_single_image=False,
+                img_list=img_list,
             )
         else:
             time.sleep(10 * (api_retry_count + 1))  # 等待一段时间后重试
@@ -133,8 +154,8 @@ class RetryHandler:
             self.platform,
             message_config["system_prompt"],
             message_config["user_text"],
-            message_config["include_img"],
-            message_config["img_list"],
+            reject_single_image=True,
+            img_list=message_config["img_list"],
         )
 
         return True, messages
@@ -158,7 +179,7 @@ class RetryHandler:
         # 打印当前的模型信息
         print_line()
         print(f"当前 云服务商: {platform}，模型: {model_name}")
-        print(e)
+        # print(e)
 
         # 获取错误信息
         error_message = self.extract_error_message(e)
@@ -183,9 +204,9 @@ class RetryHandler:
             return True, messages, True  # 需要重试且需要切换API密钥
 
         else:
-            error_message = f"其他异常错误：{e}"
-            # print(error_message)
-            raise Exception(error_message)
+            # 直接重新抛出原始异常，保持异常对象的完整性
+            # print(f"其他异常错误：{e}")
+            raise e
 
 
 class ResponseHandler:
@@ -204,7 +225,12 @@ class ResponseHandler:
             else:
                 result = timeout_handler_func(process_stream_response_func, args=(response,), execution_timeout=300)
         else:
-            result = response.choices[0].message.content
-            total_tokens = response.usage.total_tokens
+            if response.choices:
+                result = response.choices[0].message.content
+                total_tokens = response.usage.total_tokens
+            else:
+                # 如果没有choices，直接抛出原始response对象
+                print(f"响应中没有choices，原始响应：{response}")
+                raise response
 
         return result, total_tokens
